@@ -27,6 +27,7 @@ class FroalaEditor(widgets.Textarea):
         try:
             image_upload_url = reverse('froala_editor_image_upload')
             default_options['imageUploadURL'] = image_upload_url
+            default_options.update([('imageUploadParams', {'csrfmiddlewaretoken': 'csrftokenplaceholder'})])
         except NoReverseMatch:
             default_options['imageUpload'] = False
         settings_options = getattr(settings, 'FROALA_EDITOR_OPTIONS', {})
@@ -34,7 +35,7 @@ class FroalaEditor(widgets.Textarea):
         options = dict(default_options.items()).copy()
         options.update(settings_options.items())
         options.update(self.options.items())
-        options.update([('imageUploadParams', {'csrfmiddlewaretoken': 'csrftokenplaceholder'})])
+
 
         if self.theme:
             options['theme'] = self.theme
